package com.ruoyi.weighbridge.mapper;

import java.util.List;
import com.ruoyi.common.core.domain.entity.DibangDriver;

/**
 * 司机管理Mapper接口
 * 
 * @author liuhj
 * @date 2022-03-10
 */
public interface DibangDriverMapper 
{
    /**
     * 查询司机管理
     * 
     * @param driverId 司机管理主键
     * @return 司机管理
     */
    public DibangDriver selectDibangDriverByDriverId(String driverId);

    /**
     * 查询司机管理列表
     * 
     * @param dibangDriver 司机管理
     * @return 司机管理集合
     */
    public List<DibangDriver> selectDibangDriverList(DibangDriver dibangDriver);

    /**
     * 新增司机管理
     * 
     * @param dibangDriver 司机管理
     * @return 结果
     */
    public int insertDibangDriver(DibangDriver dibangDriver);

    /**
     * 修改司机管理
     * 
     * @param dibangDriver 司机管理
     * @return 结果
     */
    public int updateDibangDriver(DibangDriver dibangDriver);

    /**
     * 删除司机管理
     * 
     * @param driverId 司机管理主键
     * @return 结果
     */
    public int deleteDibangDriverByDriverId(String driverId);

    /**
     * 批量删除司机管理
     * 
     * @param driverIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDibangDriverByDriverIds(String[] driverIds);

    /**
     * 根据车牌号查询车辆
     *
     * @param plateNo 车牌号
     * @return 结果
     */
    public DibangDriver selectDibangDriverByPlateNo(String plateNo);
}
